(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('@icreate/core'), require('@icreate/ics-chromely-js-sdk')) :
    typeof define === 'function' && define.amd ? define(['@icreate/core', '@icreate/ics-chromely-js-sdk'], factory) :
    (global.icsChromelyPluginReportJsSdk = factory(global.core,global.icsChromelyRequest));
}(this, (function (core,icsChromelyRequest) { 'use strict';

    icsChromelyRequest = icsChromelyRequest && icsChromelyRequest.hasOwnProperty('default') ? icsChromelyRequest['default'] : icsChromelyRequest;

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    var Chromely$1 = /** @class */ (function () {
        function Chromely() {
            this._callbacks = {};
            var isNode = typeof window === 'undefined';
            this.isChromely = isNode ? false : !!window['CefSharp'];
            this.cefSharp = isNode ? { PostMessage: function () { } } : window['CefSharp'];
            this.baseUrl = isNode ? '' : window['Chromely'] ? window['Chromely']['baseUrl'] : '';
            this.tokenId = isNode ? '' : window['Chromely'] ? window['Chromely']['tokenId'] : '';
            this.headers = isNode ? '' : window['Chromely'] ? window['Chromely']['headers'] : {};
        }
        /**
         * 获取 Chromely 实例
         * @returns {IChromely}
         */
        Chromely.getInstance = function () {
            if (window['Chromely'] == null || window['Chromely']['cefSharp'] == null) {
                window['Chromely'] = new Chromely();
            }
            return window['Chromely'];
        };
        /**
         * 接受cef分发事件，触发容器中的该属性eventName的回调函数
         * @param {*} eventName 事件名称
         * @param {*} data 数据
         */
        Chromely.prototype.$onReceive = function (message) {
            var _a = JSON.parse(message), eventName = _a.eventName, data = _a.data;
            var callbacks = this._callbacks[eventName];
            if (!callbacks || !callbacks.length) {
                return;
            }
            for (var i = 0; i < callbacks.length; i++) {
                callbacks[i](data);
            }
        };
        /**
         * @description:订阅C#事件
         * @param {string} eventName
         * @param {Function} callback
         * @return {void}
         */
        Chromely.prototype.$on = function (eventName, callback) {
            if (!this._callbacks[eventName]) {
                this._callbacks[eventName] = [];
            }
            this._callbacks[eventName].push(callback);
        };
        /**
         * @description: 取消C#订阅事件
         * @param {string} eventName
         * @param {Function} callback
         * @return {void}
         */
        Chromely.prototype.$off = function (eventName, callback) {
            var callbacks = this._callbacks[eventName];
            if (!callbacks) {
                return;
            }
            var index = -1;
            for (var i = 0; i < callbacks.length; i++) {
                if (callbacks[i] === callback) {
                    index = i;
                    break;
                }
            }
            if (index < 0) {
                return;
            }
            this._callbacks[eventName].splice(index, 1);
        };
        /**
         * @description: 触发C#事件
         * @param {string} eventName
         * @return {void}
         */
        Chromely.prototype.$emit = function (eventName, data) {
            if (this.isChromely) {
                this.cefSharp.PostMessage(JSON.stringify({ eventName: eventName, data: data }));
            }
        };
        return Chromely;
    }());

    var Duplex;
    (function (Duplex) {
        //
        // 摘要:
        // The printer's default duplex setting.
        Duplex[Duplex["Default"] = -1] = "Default";
        //
        // 摘要:
        // Single-sided printing.
        Duplex[Duplex["Simplex"] = 1] = "Simplex";
        //
        // 摘要:
        // Double-sided, vertical printing.
        Duplex[Duplex["Vertical"] = 2] = "Vertical";
        //
        // 摘要:
        // Double-sided, horizontal printing.
        Duplex[Duplex["Horizontal"] = 3] = "Horizontal";
    })(Duplex || (Duplex = {}));

    /*
     * @Author: 文贝
     * @Date: 2022-02-11 23:21:34
     * @LastEditors: 文贝
     * @LastEditTime: 2022-10-30 21:33:43
     * @Descripttion:
     * @FilePath: \ics-chromely-plugin-core\src\ics-chromely-plugin-core.ts
     */
    var Chromely = Chromely$1.getInstance();

    var Report = /** @class */ (function () {
        function Report() {
            this.instanceId = new Date().getTime().toString();
        }
        Report.prototype.OperateEx = function (url, data, method) {
            if (method === void 0) { method = 'GET'; }
            // let opts =
            return icsChromelyRequest.function({
                url: "Report/" + url,
                method: method,
                data: __assign(__assign({}, data), { instanceId: this.instanceId })
            });
        };
        // 清空数据源
        Report.prototype.clearData = function () {
            return this.OperateEx('ClearData');
        };
        /**
         * 注册数据源
         * @param name 数据源名称
         * @param data  数据
         * @param field 指定字段对应类型 默认所有字段类型为string
         * 可指定 string|bool|date|datetime|decimal|double|float|int|long|object|short
         * 格式: {"id":"string","flag":"int","birthday":"date","total":"decimal"}
         * @returns
         */
        Report.prototype.registerData = function (name, data, field) {
            return this.OperateEx('RegisterData', { name: name, data: JSON.stringify(data), field: JSON.stringify(field || {}) }, 'POST');
        };
        // 设置双面打印
        Report.prototype.doublePass = function (value) {
            return this.OperateEx('DoublePass', { value: value });
        };
        // 指定文件加载报表
        Report.prototype.load = function (fileName) {
            return this.OperateEx('Load', { fileName: fileName });
        };
        // 根据Id加载报表
        Report.prototype.loadFromId = function (reportId) {
            return this.OperateEx('LoadFromId', { reportId: reportId });
        };
        // 根据Id加载报表
        Report.prototype.loadFromString = function (content) {
            return this.OperateEx('loadFromString', { content: content });
        };
        /**
         * 导出pdf
         * @param fileName 文件名称，如果不传则返回流
         * @returns 文件或者文件流
         */
        Report.prototype.ExportToPdf = function (fileName) {
            if (fileName) {
                return this.OperateEx('ExportToPdf', { fileName: fileName });
            }
            else {
                return this.OperateEx('ExportToPdfStream', null, 'GET');
            }
        };
        //  导出html
        Report.prototype.exportToHtml = function (fileName) {
            return this.OperateEx('ExportToHtml', { fileName: fileName });
        };
        // 准备报表
        Report.prototype.prepare = function (append) {
            if (append === void 0) { append = false; }
            return this.OperateEx('Prepare', { append: append });
        };
        // 添加参数
        Report.prototype.addParameter = function (name, value) {
            return this.OperateEx('AddParameter', { name: name, value: value });
        };
        /**
         * 获取报表内容
         * @returns 报表内容
         */
        Report.prototype.content = function () {
            return this.OperateEx('Content');
        };
        /**
         * 设计报表
         * @param saveAction 保存回调
         * @returns
         */
        Report.prototype.design = function (saveAction) {
            var _this = this;
            if (saveAction) {
                Chromely.$on('on-report-save-click', function (data) {
                    if (data.instanceId === _this.instanceId) {
                        saveAction(data);
                    }
                });
                return this.OperateEx('Design', { customSave: true });
            }
            else {
                return this.OperateEx('Design');
            }
        };
        // 预览报表
        Report.prototype.show = function (printerName, showPrintSettings, closeAfterPrint) {
            return this.OperateEx('Show', {
                printerName: printerName !== null && printerName !== void 0 ? printerName : '',
                showPrintSettings: showPrintSettings !== null && showPrintSettings !== void 0 ? showPrintSettings : false,
                closeAfterPrint: closeAfterPrint !== null && closeAfterPrint !== void 0 ? closeAfterPrint : false
            });
        };
        // 预览准备报表
        Report.prototype.showPrepared = function (printerName, showPrintSettings, closeAfterPrint) {
            return this.OperateEx('ShowPrepared', {
                printerName: printerName !== null && printerName !== void 0 ? printerName : '',
                showPrintSettings: showPrintSettings !== null && showPrintSettings !== void 0 ? showPrintSettings : false,
                closeAfterPrint: closeAfterPrint !== null && closeAfterPrint !== void 0 ? closeAfterPrint : false
            });
        };
        // 打印报表
        Report.prototype.print = function (printerName, showPrintSettings) {
            return this.OperateEx('Print', {
                printerName: printerName !== null && printerName !== void 0 ? printerName : '',
                showPrintSettings: showPrintSettings !== null && showPrintSettings !== void 0 ? showPrintSettings : false
            });
        };
        // 打印准备报表
        Report.prototype.printPrepared = function (printerName, showPrintSettings) {
            return this.OperateEx('PrintPrepared', {
                printerName: printerName !== null && printerName !== void 0 ? printerName : '',
                showPrintSettings: showPrintSettings !== null && showPrintSettings !== void 0 ? showPrintSettings : false
            });
        };
        // 释放报表
        Report.prototype.dispose = function () {
            return this.OperateEx('Dispose');
        };
        return Report;
    }());

    /*
     * @Author: 文贝
     * @Date: 2022-02-11 23:21:34
     * @LastEditors: 刘邓
     * @LastEditTime: 2022-05-10 17:11:36
     * @Descripttion:
     * @FilePath: \src\ics-chromely-plugin-report-js-sdk.ts
     */

    return Report;

})));
//# sourceMappingURL=ics-chromely-plugin-report-js-sdk.umd.js.map
